==> huaweicloudsdkaad-3.1.86-py2.py3-none-any.whl: huaweicloudsdkaad/v1/model/batch_transfer_rule_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchTransferRuleBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'rules': 'list[TransferRuleBody]'
    }

    attribute_map = {
        'rules': 'rules'
    }

    def __init__(self, rules=None):
        """BatchTransferRuleBody

        The model defined in huaweicloud sdk

        :param rules: 批量转发规则
        :type rules: list[:class:`huaweicloudsdkaad.v1.TransferRuleBody`]
        """
        
        

        self._rules = None
        self.discriminator = None

        if rules is not None:
            self.rules = rules

    @property
    def rules(self):
        """Gets the rules of this BatchTransferRuleBody.

        批量转发规则

        :return: The rules of this BatchTransferRuleBody.
        :rtype: list[:class:`huaweicloudsdkaad.v1.TransferRuleBody`]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this BatchTransferRuleBody.

        批量转发规则

        :param rules: The rules of this BatchTransferRuleBody.
        :type rules: list[:class:`huaweicloudsdkaad.v1.TransferRuleBody`]
        """
        self._rules = rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchTransferRuleBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkaad-3.1.156-py2.py3-none-any.whl: huaweicloudsdkaad/v1/model/batch_transfer_rule_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchTransferRuleBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'rules': 'list[TransferRuleBody]'
    }

    attribute_map = {
        'rules': 'rules'
    }

    def __init__(self, rules=None):
        r"""BatchTransferRuleBody

        The model defined in huaweicloud sdk

        :param rules: 批量转发规则
        :type rules: list[:class:`huaweicloudsdkaad.v1.TransferRuleBody`]
        """
        
        

        self._rules = None
        self.discriminator = None

        if rules is not None:
            self.rules = rules

    @property
    def rules(self):
        r"""Gets the rules of this BatchTransferRuleBody.

        批量转发规则

        :return: The rules of this BatchTransferRuleBody.
        :rtype: list[:class:`huaweicloudsdkaad.v1.TransferRuleBody`]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        r"""Sets the rules of this BatchTransferRuleBody.

        批量转发规则

        :param rules: The rules of this BatchTransferRuleBody.
        :type rules: list[:class:`huaweicloudsdkaad.v1.TransferRuleBody`]
        """
        self._rules = rules

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchTransferRuleBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
